==> wsclient-8.0.4-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wsresources/WsResourcesPingRequestWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wsresources;



/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2019 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: WsResourcesPingRequestWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wsresources.v1_00.WsResourcesPingRequest
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wsresources
 * TimeStamp: 2021-03-26T16:29:03.969Z
 */
public class WsResourcesPingRequestWrapper
{

	public WsResourcesPingRequestWrapper() {}

	public org.hpccsystems.ws.client.gen.axis2.wsresources.v1_00.WsResourcesPingRequest getRaw()
	{
		org.hpccsystems.ws.client.gen.axis2.wsresources.v1_00.WsResourcesPingRequest raw = new org.hpccsystems.ws.client.gen.axis2.wsresources.v1_00.WsResourcesPingRequest();
		return raw;
	}


}

==> wsclient-9.4.24-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wsresources/WsResourcesPingRequestWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wsresources;

/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2021 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: WsResourcesPingRequestWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wsresources.latest.WsResourcesPingRequest
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wsresources
 */
public class WsResourcesPingRequestWrapper
{

    public WsResourcesPingRequestWrapper() {}

    public org.hpccsystems.ws.client.gen.axis2.wsresources.latest.WsResourcesPingRequest getRaw()
    {
        org.hpccsystems.ws.client.gen.axis2.wsresources.latest.WsResourcesPingRequest raw = new org.hpccsystems.ws.client.gen.axis2.wsresources.latest.WsResourcesPingRequest();
        return raw;
    }


}
